@@ -89,6 +89,7 @@ def validate_config_settings(config_file: Path) -> None:
         "parameters",
         "alerts",
         "dimensions",
+        "functions",
     )
 
     core_config_keys_specified = config.keys()
@@ -200,7 +201,7 @@ class DefinitionConfig(Config):
 
 def entity_from_path(
     path: Path, is_private: bool = False
-) -> Union[Config, Outcome, DefaultConfig, DefinitionConfig]:
+) -> Union[Config, Outcome, DefaultConfig, DefinitionConfig, FunctionsSpec]:
     is_outcome = path.parent.parent.name == OUTCOMES_DIR
     is_default_config = path.parent.name == DEFAULTS_DIR
     is_definition_config = path.parent.name == DEFINITIONS_DIR
@@ -233,13 +234,16 @@ def entity_from_path(
                 is_private=is_private,
             )
     elif is_definition_config:
-        return DefinitionConfig(
-            slug=slug,
-            spec=DefinitionSpec.from_dict(config_dict),
-            last_modified=dt.datetime.fromtimestamp(path.stat().st_mtime, UTC),
-            platform=slug,
-            is_private=is_private,
-        )
+        if path.name == FUNCTIONS_FILE:
+            return FunctionsSpec.from_dict(config_dict)
+        else:
+            return DefinitionConfig(
+                slug=slug,
+                spec=DefinitionSpec.from_dict(config_dict),
+                last_modified=dt.datetime.fromtimestamp(path.stat().st_mtime, UTC),
+                platform=slug,
+                is_private=is_private,
+            )
 
     if "project" in config_dict:
         # config is from opmon
@@ -289,7 +293,7 @@ class ConfigCollection:
             external_configs = []
 
             for config_file in tmp_dir.glob("*.toml"):
-                last_modified = next(repo.iter_commits("main", paths=config_file)).committed_date
+                last_modified = next(repo.iter_commits("HEAD", paths=config_file)).committed_date
                 config_json = toml.load(config_file)
 
                 if "project" in config_json:
@@ -310,7 +314,7 @@ class ConfigCollection:
 
             outcomes = []
             for outcome_file in tmp_dir.glob(f"**/{OUTCOMES_DIR}/*/*.toml"):
-                commit_hash = next(repo.iter_commits("main", paths=outcome_file)).hexsha
+                commit_hash = next(repo.iter_commits("HEAD", paths=outcome_file)).hexsha
 
                 outcomes.append(
                     Outcome(
@@ -325,7 +329,7 @@ class ConfigCollection:
             default_configs = []
             for default_config_file in tmp_dir.glob(f"**/{DEFAULTS_DIR}/*.toml"):
                 last_modified = next(
-                    repo.iter_commits("main", paths=default_config_file)
+                    repo.iter_commits("HEAD", paths=default_config_file)
                 ).committed_date
 
                 default_config_json = toml.load(default_config_file)
@@ -349,7 +353,7 @@ class ConfigCollection:
             definitions = []
             for definitions_config_file in tmp_dir.glob(f"**/{DEFINITIONS_DIR}/*.toml"):
                 last_modified = next(
-                    repo.iter_commits("main", paths=definitions_config_file)
+                    repo.iter_commits("HEAD", paths=definitions_config_file)
                 ).committed_date
 
                 definitions.append(
